@@ -42,11 +42,11 @@ class Entry:
         if not short and self.journal.config['linewrap']:
             title = textwrap.fill(date_str + " " + self.title, self.journal.config['linewrap'])
             body = "\n".join([
-                    textwrap.fill(line+" ",
+                    textwrap.fill((line + " ") if (len(line) == 0) else line,
                         self.journal.config['linewrap'],
                         initial_indent="| ",
                         subsequent_indent="| ",
-                        drop_whitespace=False).replace('  ', ' ')
+                        drop_whitespace=False)
                     for line in self.body.strip().splitlines()
                 ])
         else:
